pub enum CollectionErrorKind {
NotFound,
Unidentified,
Syntax,
StorageCorrupted,
Io,
Other,
}Expand description
Collection error kind.
Variants
NotFound
Entity not found, so the requested operation could not be performed.
Unidentified
Entity doesn’t have an id, and the requested operation could not be performed.
Syntax
Serialization/deserialization error.
StorageCorrupted
Storage is in an invalid state and cannot perform the requested operation.
Io
Io error (unexpected EOF, interrupted, …).
Other
Other error.